@@ -4,11 +4,24 @@ as.matrix.DGEList <- function(x,...) as.matrix(x$counts)
 
 # S3 as.data.frame method
 
+as.data.frame.DGEList <- function(x,row.names=NULL,...)
+#	Created 17 June 2020.
+{
+	if(is.null(x$genes)) {
+		data.frame(x$counts,row.names=row.names,check.rows=FALSE,check.names=FALSE,stringsAsFactors=FALSE)
+	} else {
+		if(is.null(row.names)) {
+			rn <- rownames(x$counts)
+			if(!is.null(rn) && !anyDuplicated(rn)) row.names(x$genes) <- rn
+		}
+		data.frame(x$genes,x$counts,row.names=row.names,check.rows=FALSE,check.names=FALSE,stringsAsFactors=FALSE)
+	}
+}
 as.data.frame.DGEExact <- as.data.frame.DGELRT <- function(x,row.names=NULL,...)
 {
 	if(is.null(x$genes)) {
 		if(!is.null(row.names)) row.names(x$table) <- row.names
-		x$table		
+		x$table
 	} else
 		data.frame(x$genes,x$table,row.names=row.names,check.rows=FALSE,check.names=FALSE,stringsAsFactors=FALSE)
 }
